==> cloudtoken-plugin.okta-0.0.1.tar.gz: cloudtoken-plugin.okta-0.0.1/README.md <==
# Cloudtoken OKTA Auth Plugin

This is an OKTA auth plugin for [Cloudtoken](https://bitbucket.org/atlassian/cloudtoken).

## Installation

    $ pip3 install cloudtoken-plugin.okta

## Configuring Cloudtoken

You will need to add the `okta` plugin to auth section your `~/.config/cloudtoken/config.yaml` and have the `saml` plugin
immediately after it. You `config.yaml` should look something like this: 

    auth:
        - okta
        - saml

You will also need to add the OKTA url into `config.yaml` as a top level key. Your config.yaml should look something
like this:

    okta_url: 'https://mydomain.okta.com/'
    plugins:
        pre_auth:
        auth:
            - idp
            - saml
        post_auth:
            - export_credentials_shell


## 401's when authenticating?
IIS might be trying to authenticate your credentials using Windows Authentication instead of Forms authentication.

You can follow the instructions [here](http://www.richardawilson.com/2010/10/adfs-20-login-page.html) to fix that.

## Contributors

Pull requests, issues and comments welcome. For pull requests:

* Add tests for new features and bug fixes
* Follow the existing style
* Separate unrelated changes into multiple pull requests

See the existing issues for things to start contributing.

For bigger changes, make sure you start a discussion first by creating
an issue and explaining the intended change.

Atlassian requires contributors to sign a Contributor License Agreement,
known as a CLA. This serves as a record stating that the contributor is
entitled to contribute the code/documentation/translation to the project
and is willing to have it used in distributions and derivative works
(or is willing to transfer ownership).

Prior to accepting your contributions we ask that you please follow the appropriate
link below to digitally sign the CLA. The Corporate CLA is for those who are
contributing as a member of an organization and the individual CLA is for
those contributing as an individual.

* [CLA for corporate contributors](https://na2.docusign.net/Member/PowerFormSigning.aspx?PowerFormId=e1c17c66-ca4d-4aab-a953-2c231af4a20b)
* [CLA for individuals](https://na2.docusign.net/Member/PowerFormSigning.aspx?PowerFormId=3f94fbdc-2fbe-46ac-b14c-5d152700ae5d)

## License

Copyright (c) 2016 Atlassian and others.
Apache 2.0 licensed, see [LICENSE.txt](LICENSE.txt) file.

==> cloudtoken-plugin.okta-0.0.6.tar.gz: cloudtoken-plugin.okta-0.0.6/README.md <==
# Cloudtoken OKTA Auth Plugin

This is an OKTA auth plugin for [Cloudtoken](https://bitbucket.org/atlassian/cloudtoken).

## Installation

    $ pip3 install cloudtoken-plugin.okta

## Configuring Cloudtoken

You will need to add the `okta` plugin to auth section your `~/.config/cloudtoken/config.yaml` and have the `saml` plugin
immediately after it. You `config.yaml` should look something like this: 

    auth:
        - okta
        - saml

You will also need to add both a gui flag (for an ugly, but functional popup), and the OKTA url into `config.yaml` as a top level key. Your config.yaml should look something
like this:

    okta_url: 'https://mydomain.okta.com/'
    gui: True
    plugins:
        pre_auth:
        auth:
            - okta
            - saml
        post_auth:
            - export_credentials_shell


## 401's when authenticating?
IIS might be trying to authenticate your credentials using Windows Authentication instead of Forms authentication.

You can follow the instructions [here](http://www.richardawilson.com/2010/10/adfs-20-login-page.html) to fix that.

## Contributors

Pull requests, issues and comments welcome. For pull requests:

* Add tests for new features and bug fixes
* Follow the existing style
* Separate unrelated changes into multiple pull requests

See the existing issues for things to start contributing.

For bigger changes, make sure you start a discussion first by creating
an issue and explaining the intended change.

Atlassian requires contributors to sign a Contributor License Agreement,
known as a CLA. This serves as a record stating that the contributor is
entitled to contribute the code/documentation/translation to the project
and is willing to have it used in distributions and derivative works
(or is willing to transfer ownership).

Prior to accepting your contributions we ask that you please follow the appropriate
link below to digitally sign the CLA. The Corporate CLA is for those who are
contributing as a member of an organization and the individual CLA is for
those contributing as an individual.

* [CLA for corporate contributors](https://na2.docusign.net/Member/PowerFormSigning.aspx?PowerFormId=e1c17c66-ca4d-4aab-a953-2c231af4a20b)
* [CLA for individuals](https://na2.docusign.net/Member/PowerFormSigning.aspx?PowerFormId=3f94fbdc-2fbe-46ac-b14c-5d152700ae5d)

## License

Copyright (c) 2016 Atlassian and others.
Apache 2.0 licensed, see [LICENSE.txt](LICENSE.txt) file.
